.. include:: links.rst


Installation
------------

.. code:: bash

    $ pip install tatsu

.. warning::
    Versions of |TatSu| since 5.0.0 may require Python>=3.8. Python 2.7 is no longer supported

